Learn R Programming

EGSEA (version 1.0.3)

buildCustomIdxEZID: Custom Gene Set Collection Index

Description

It creates gene set collections from a given list of gene sets to be used for the EGSEA analysis.

Usage

buildCustomIdxEZID(entrezIDs, gsets, anno = NULL, label = "custom", name = "Custom", species = "Human", min.size = 1)

Arguments

entrezIDs
character, a vector that stores the Entrez Gene IDs tagged in your dataset. The order of the Entrez Gene IDs should match those of the count/expression matrix row names.
gsets
list, list of gene sets. Each gene set is character vector of Enterz IDs. The names of the list should match the GeneSet column in the anno argument (if it is provided).
anno
list, dataframe that stores a detailed annotation for each gene set. Some of its fields can be ID, GeneSet, PubMed, URLs, etc. The GeneSet field is mandatory and should have the same names as the gsets' names.
label
character,a unique id that identifies the collection of gene sets
name
character,the collection name to be used in the EGSEA report
species
character, determine the organism of selected gene sets: "human", "mouse" or "rat".
min.size
integer, the minium number of genes required in a testing gene set

Value

indexed gene set annotation that can be used with other functions in the package. Each annotation is a list of seven elements: original stores the original gene sets, idx stores the indexed gene sets, anno that stores detailed annotation for each gene set, label a unique id that identifies the collection of gene sets, featureIDs stores the entrezIDs used in building the annotation, species stores that organism name of gene sets and name stores the collection name to be used in the EGSEA report.

Details

It indexes newly created gene sets and attach gene set annotation if provided.

Examples

Run this code
library(EGSEAdata) 
data(il13.data)
v = il13.data$voom
kegg = buildIdxEZID(entrezIDs=rownames(v$E), species="human", 
msigdb.gsets="none", 
         kegg.updated=FALSE, kegg.exclude = c("Metabolism"))
gsets = kegg$kegg$original[1:50]
gs.annots = buildCustomIdxEZID(entrezIDs=rownames(v$E), gsets= gsets, 
species="human")
names(gs.annots)


Run the code above in your browser using DataLab