Learn R Programming

EGSEA (version 1.0.3)

buildGeneSetDBIdxEZID: Gene Set Collection Indexes from the GeneSetDB Database

Description

It prepares the GeneSetDB gene set collections to be used for the EGSEA analysis.

Usage

buildGeneSetDBIdxEZID(entrezIDs, species, by.category = TRUE, min.size = 1, rdata.dir = NULL)

Arguments

entrezIDs
character, a vector that stores the Entrez Gene IDs tagged in your dataset. The order of the Entrez Gene IDs should match those of the count/expression matrix row names.
species
character, determine the organism of selected gene sets: "human", "mouse" or "rat".
by.category
logical, whether to group the gene sets into collections or not. Default TRUE.
min.size
integer, the minium number of genes required in a testing gene set
rdata.dir
character, directory from which the GeneSetDB collections are loaded. If NULL, EGSEA tries to load the data from EGSEAdata.

Value

indexed gene set annotation that can be used with other functions in the package. Each annotation is a list of seven elements: original stores the original gene sets, idx stores the indexed gene sets, anno that stores detailed annotation for each gene set, label a unique id that identifies the collection of gene sets, featureIDs stores the entrezIDs used in building the annotation, species stores that organism name of gene sets and name stores the collection name to be used in the EGSEA report.

Details

It indexes the GeneSetDB gene sets and loads gene set annotation.

Examples

Run this code
library(EGSEAdata)
data(il13.data)
v = il13.data$voom
gs.annots = buildGeneSetDBIdxEZID(entrezIDs=rownames(v$E), species="human")
names(gs.annots)


Run the code above in your browser using DataLab