Learn R Programming

EGSEA (version 1.0.3)

buildKEGGIdxEZID: Gene Set Collection Index from the KEGG Database

Description

It prepares the KEGG pathway collection to be used for the EGSEA analysis.

Usage

buildKEGGIdxEZID(entrezIDs, species = "human", min.size = 1, updated = FALSE, rdata.dir = NULL)

Arguments

entrezIDs
character, a vector that stores the Entrez Gene IDs tagged in your dataset. The order of the Entrez Gene IDs should match those of the count/expression matrix row names.
species
character, determine the organism of selected gene sets: "human", "mouse" or "rat".
min.size
integer, the minium number of genes required in a testing gene set
updated
logical, set to TRUE if you want to download the most recent KEGG pathways.
rdata.dir
character, directory from which the KEGG pathway collections are loaded. If NULL, EGSEA tries to load the data from EGSEAdata.

Value

indexed gene set annotation that can be used with other functions in the package. Each annotation is a list of seven elements: original stores the original gene sets, idx stores the indexed gene sets, anno that stores detailed annotation for each gene set, label a unique id that identifies the collection of gene sets, featureIDs stores the entrezIDs used in building the annotation, species stores that organism name of gene sets and name stores the collection name to be used in the EGSEA report.

Details

It indexes the KEGG pathway gene sets and loads gene set annotation.

Examples

Run this code
library(EGSEAdata)
data(il13.data)
v = il13.data$voom
gs.annots = buildKEGGIdxEZID(entrezIDs=rownames(v$E), species="human")

Run the code above in your browser using DataLab