character, a vector that stores the Entrez Gene IDs tagged
in your dataset.
The order of the Entrez Gene IDs should match those of the count/expression
matrix row names.
geneSets
character, a vector determines which gene set collections
should be used.
It can take values from this list: "h", "c1", "c2", "c3", "c4", "c5",
"c6","c7". "h" and "c1"
are human specific. If NULL, all available gene set collections are loaded.
species
character, determine the organism of selected gene sets:
"human", "mouse" or "rat".
min.size
integer, the minium number of genes required in a testing
gene set
rdata.dir
character, directory from which the MSigDB collections are
loaded.
If NULL, EGSEA tries to load the data from EGSEAdata.
Value
indexed gene set annotation that can be used with other functions in
the package.
Each annotation is a list of seven elements: original stores the
original gene sets,
idx stores the indexed gene sets, anno that stores detailed
annotation for each
gene set, label a unique id that identifies the collection of gene
sets,
featureIDs stores the entrezIDs used in building the annotation,
species
stores that organism name of gene sets and name stores the
collection name
to be used in the EGSEA report.
Details
It indexes the MSigDB gene sets and loads gene set annotation.