Usage
egsea.ora(entrezIDs, universe = NULL, logFC = NULL, title = NULL, gs.annots, symbolsMap = NULL, minSize = 2, display.top = 20, sort.by = "p.adj", egsea.dir = "./", kegg.dir = NULL, logFC.cutoff = 0, sum.plot.axis = "p.adj", sum.plot.cutoff = NULL, vote.bin.width = 5, num.threads = 4, report = TRUE, print.base = FALSE, verbose = FALSE)
Arguments
entrezIDs
character, a vector of Entrez Gene IDs to be tested for ORA.
universe
character, a vector of Enterz IDs to be used as a background
list. If
universe=NULL, the background list is created from the AnnotationDbi
package.
logFC
double, is a matrix or vector of log fold changes of the same
length of entrezIDs.
If logFC=NULL, 1 is used as a default value. Then, the regulation direction
in heatmaps
and pathway maps is not indicative to the gene regulation direction.
title
character, a short description of the experimental contrast.
symbolsMap
dataframe, an K x 2 matrix stores the gene symbol of each
Entrez Gene ID. It
is used for the heatmap visualization. The order of rows should match that
of the
entrezIDs. Default symbolsMap=NULL.
minSize
integer, the minimum size of a gene set to be included in the
analysis.
Default minSize= 2.
display.top
integer, the number of top gene sets to be displayed in
the EGSEA report.
You can always access the list of all tested gene sets using the returned
gsa list.
Default is 20.
sort.by
character, determines how to order the analysis results in
the stats table.
It takes "p.value", "p.adj" or "Significance".
egsea.dir
character, directory into which the analysis results are
written out.
kegg.dir
character, the directory of KEGG pathway data file (.xml)
and image file (.png).
Default kegg.dir=paste0(egsea.dir, "/kegg-dir/").
logFC.cutoff
numeric, cut-off threshold of logFC and is used for
Sginificance Score
and Regulation Direction Calculations. Default logFC.cutoff=0.
sum.plot.axis
character, the x-axis of the summary plot. All the
values accepted by the
sort.by parameter can be used. Default sum.plot.axis="p.adj".
sum.plot.cutoff
numeric, cut-off threshold to filter the gene sets of
the summary plots
based on the values of the sum.plot.axis. Default
sum.plot.cutoff=NULL.
vote.bin.width
numeric, the bin width of the vote ranking. Default
vote.bin.width=5.
num.threads
numeric, number of CPU threads to be used. Default
num.threads=2.
report
logical, whether to generate the EGSEA interactive report. It
takes longer time
to run. Default is True.
print.base
logical, whether to write out the results of the
individual GSE methods.
Default FALSE.
verbose
logical, whether to print out progress messages and warnings.