Learn R Programming

EGSEA (version 1.0.3)

egsea.sort: EGSEA Result Sorting Options

Description

It lists the accepted sorting methods for analysis results

Usage

egsea.sort()

Arguments

Value

It returns a character vector of the accepted values for the sort.by argument in egsea

Examples

Run this code
egsea.sort()

Run the code above in your browser using DataLab