Arguments
entrezIDs
character, a vector that stores the Entrez Gene IDs tagged
in your dataset.
The order of the Entrez Gene IDs should match those of the count/expression
matrix row names.
gsets
list, list of gene sets. Each gene set is character vector of
Enterz IDs.
The names of the list should match the GeneSet column in the anno
argument (if it is provided).
anno
list, dataframe that stores a detailed annotation for each gene
set.
Some of its fields can be ID, GeneSet, PubMed, URLs, etc. The GeneSet field
is mandatory and
should have the same names as the gsets' names.
label
character,a unique id that identifies the collection of gene
sets
name
character,the collection name to be used in the EGSEA report
species
character, determine the organism of selected gene sets:
"human", "mouse" or "rat".
min.size
integer, the minium number of genes required in a testing
gene set