Arguments
entrezIDs
character, a vector that stores the Entrez Gene IDs tagged
in your dataset.
The order of the Entrez Gene IDs should match those of the count/expression
matrix row names.
species
character, determine the organism of selected gene sets:
"human", "mouse" or "rat".
by.category
logical, whether to group the gene sets into collections
or not. Default TRUE.
min.size
integer, the minium number of genes required in a testing
gene set
rdata.dir
character, directory from which the GeneSetDB collections
are loaded.
If NULL, EGSEA tries to load the data from EGSEAdata.