Arguments
entrezIDs
character, a vector that stores the Entrez Gene IDs tagged
in your dataset.
The order of the Entrez Gene IDs should match those of the count/expression
matrix row names.
species
character, determine the organism of selected gene sets:
"human", "mouse" or "rat".
msigdb.gsets
character, a vector determines which gene set
collections should be used.
It can take values from this list: "h", "c1", "c2", "c3", "c4", "c5",
"c6","c7". "h" and "c1"
are human specific. If NULL, all available gene set collections are loaded.
If "none",
MSigDB collections are excluded.
kegg.updated
logical, set to TRUE if you want to download the most
recent KEGG pathways.
kegg.exclude
character, vector used to exclude KEGG pathways of
specific type(s):
Disease, Metabolism, Signaling. If "all", none fo the KEGG collections is
included.
min.size
integer, the minium number of genes required in a testing
gene set
rdata.dir
character, directory from which the MSigDB collections are
loaded.
If NULL, EGSEA tries to load the data from EGSEAdata.