Arguments
entrezIDs
character, a vector that stores the Entrez Gene IDs tagged
in your dataset.
The order of the Entrez Gene IDs should match those of the count/expression
matrix row names.
species
character, determine the organism of selected gene sets:
"human", "mouse" or "rat".
min.size
integer, the minium number of genes required in a testing
gene set
updated
logical, set to TRUE if you want to download the most recent
KEGG pathways.
rdata.dir
character, directory from which the KEGG pathway
collections are loaded.
If NULL, EGSEA tries to load the data from EGSEAdata.